@@ -727,7 +727,7 @@ class TkeClient(AbstractClient):
 
 
     def DeletePrometheusTemplate(self, request):
-        """删除一个云原生Promehtheus配置模板
+        """删除一个云原生Prometheus配置模板
 
         :param request: Request instance for DeletePrometheusTemplate.
         :type request: :class:`tencentcloud.tke.v20180525.models.DeletePrometheusTemplateRequest`
@@ -866,6 +866,34 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeClusterCommonNames(self, request):
+        """获取指定子账户在RBAC授权模式中对应kube-apiserver客户端证书的CommonName字段，如果没有客户端证书，将会签发一个，此接口有最大传入子账户数量上限，当前为50
+
+        :param request: Request instance for DescribeClusterCommonNames.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DescribeClusterCommonNamesRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DescribeClusterCommonNamesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeClusterCommonNames", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeClusterCommonNamesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeClusterEndpointStatus(self, request):
         """查询集群访问端口状态(独立集群开启内网/外网访问，托管集群支持开启内网访问)
 
@@ -1202,6 +1230,34 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeEnableVpcCniProgress(self, request):
+        """本接口用于查询开启vpc-cni模式的任务进度
+
+        :param request: Request instance for DescribeEnableVpcCniProgress.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DescribeEnableVpcCniProgressRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DescribeEnableVpcCniProgressResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeEnableVpcCniProgress", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeEnableVpcCniProgressResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeExistedInstances(self, request):
         """查询已经存在的节点，判断是否可以加入集群
 
@@ -1538,6 +1594,34 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def EnableVpcCniNetworkType(self, request):
+        """GR集群可以通过本接口附加vpc-cni容器网络插件，开启vpc-cni容器网络能力
+
+        :param request: Request instance for EnableVpcCniNetworkType.
+        :type request: :class:`tencentcloud.tke.v20180525.models.EnableVpcCniNetworkTypeRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.EnableVpcCniNetworkTypeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("EnableVpcCniNetworkType", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.EnableVpcCniNetworkTypeResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetUpgradeInstanceProgress(self, request):
         """获得节点升级当前的进度
 
@@ -1790,6 +1874,34 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def SetNodePoolNodeProtection(self, request):
+        """仅能设置节点池中处于伸缩组的节点
+
+        :param request: Request instance for SetNodePoolNodeProtection.
+        :type request: :class:`tencentcloud.tke.v20180525.models.SetNodePoolNodeProtectionRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.SetNodePoolNodeProtectionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("SetNodePoolNodeProtection", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.SetNodePoolNodeProtectionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def SyncPrometheusTemplate(self, request):
         """同步模板到实例或者集群
 
